@@ -34,7 +34,7 @@ DEBUG_LOGGING_MAP = {
 }
 
 PROG_NAME = "slcli (SoftLayer Command-line)"
-VALID_FORMATS = ['table', 'raw', 'json', 'jsonraw']
+VALID_FORMATS = ['table', 'raw', 'json', 'jsonraw', 'csv']
 DEFAULT_FORMAT = 'raw'
 
 if sys.stdout.isatty():
@@ -118,6 +118,7 @@ def cli(env,
     env.skip_confirmations = really
     env.config_file = config
     env.format = format
+    env.set_env_theme(config_file=config)
     env.ensure_client(config_file=config, is_demo=demo, proxy=proxy)
     env.vars['_start'] = time.time()
     logger = logging.getLogger()
