@@ -54,6 +54,9 @@ ALL_ROUTES = [
     ('virtual:migrate', 'SoftLayer.CLI.virt.migrate:cli'),
     ('virtual:access', 'SoftLayer.CLI.virt.access:cli'),
     ('virtual:monitoring', 'SoftLayer.CLI.virt.monitoring:cli'),
+    ('virtual:notifications', 'SoftLayer.CLI.virt.notifications:cli'),
+    ('virtual:notification-add', 'SoftLayer.CLI.virt.notification_add:cli'),
+    ('virtual:notification-delete', 'SoftLayer.CLI.virt.notification_delete:cli'),
 
     ('dedicatedhost', 'SoftLayer.CLI.dedicatedhost'),
     ('dedicatedhost:list', 'SoftLayer.CLI.dedicatedhost.list:cli'),
@@ -292,6 +295,10 @@ ALL_ROUTES = [
     ('hardware:upgrade', 'SoftLayer.CLI.hardware.upgrade:cli'),
     ('hardware:sensor', 'SoftLayer.CLI.hardware.sensor:cli'),
     ('hardware:monitoring', 'SoftLayer.CLI.hardware.monitoring:cli'),
+    ('hardware:notifications', 'SoftLayer.CLI.hardware.notifications:cli'),
+    ('hardware:notification-add', 'SoftLayer.CLI.hardware.notification_add:cli'),
+    ('hardware:notification-delete', 'SoftLayer.CLI.hardware.notification_delete:cli'),
+    ('hardware:create-credential', 'SoftLayer.CLI.hardware.create_credential:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
