@@ -845,7 +845,7 @@ getApplicationDeliveryControllers = [
         'createDate': '2015-05-05T16:23:52-06:00',
         'id': 11449,
         'modifyDate': '2015-05-05T16:24:09-06:00',
-        'name': 'SLADC307608-1',
+        'name': 'TEST307608-1',
         'typeId': 2,
         'description': 'Citrix NetScaler VPX 10.5 10Mbps Standard',
         'managementIpAddress': '10.11.11.112',
