@@ -34,6 +34,60 @@ getObject = {
                 'nextInvoiceTotalRecurringAmount': 1
             }
         ],
+        "nextInvoiceChildren": [
+            {
+                "allowCancellationFlag": 1,
+                "associatedBillingItemId": "738974962",
+                "cancellationDate": "2022-11-03T23:00:01-06:00",
+                "categoryCode": "os_usage",
+                "createDate": "2022-10-04T17:00:08-06:00",
+                "cycleStartDate": "2022-10-04T17:00:08-06:00",
+                "description": "CentOS 8.x Usage is 743.9997 hours Used",
+                "id": 999303609,
+                "laborFee": "0",
+                "laborFeeTaxRate": "0",
+                "lastBillDate": None,
+                "modifyDate": None,
+                "nextBillDate": "2022-11-03T23:00:00-06:00",
+                "oneTimeFee": "0",
+                "oneTimeFeeTaxRate": "0",
+                "orderItemId": None,
+                "parentId": None,
+                "recurringFee": "0",
+                "recurringFeeTaxRate": "0",
+                "recurringMonths": 1,
+                "serviceProviderId": 1,
+                "setupFee": "0",
+                "setupFeeTaxRate": "0",
+                "associatedBillingItem": None
+            },
+            {
+                "allowCancellationFlag": 1,
+                "associatedBillingItemId": "738974962",
+                "cancellationDate": "2022-11-03T23:00:01-06:00",
+                "categoryCode": "guest_core_usage",
+                "createDate": "2022-10-04T17:00:09-06:00",
+                "cycleStartDate": "2022-10-04T17:00:09-06:00",
+                "description": "CPU Cores: a suspendable product.",
+                "id": 999303621,
+                "laborFee": "0",
+                "laborFeeTaxRate": "0",
+                "lastBillDate": None,
+                "modifyDate": None,
+                "nextBillDate": "2022-11-03T23:00:00-06:00",
+                "oneTimeFee": "0",
+                "oneTimeFeeTaxRate": "0",
+                "orderItemId": None,
+                "parentId": None,
+                "recurringFee": "1.54",
+                "recurringFeeTaxRate": "0",
+                "recurringMonths": 1,
+                "serviceProviderId": 1,
+                "setupFee": "0",
+                "setupFeeTaxRate": "0",
+                "associatedBillingItem": None
+            },
+        ],
         'package': {
             "id": 835,
             "keyName": "PUBLIC_CLOUD_SERVER"
@@ -75,7 +129,7 @@ getObject = {
         'passwords': [{'username': 'user', 'password': 'pass'}],
         'softwareLicense': {
             'softwareDescription': {'version': '12.04-64 Minimal for VSI',
-                                    'name': 'Ubuntu'}}
+                                    'name': 'Ubuntu', 'referenceCode': 'UBUNTU_8_64', }}
     },
     'softwareComponents': [{
         'passwords': [{'username': 'user', 'password': 'pass'}],
