@@ -12,7 +12,7 @@ from SoftLayer.exceptions import SoftLayerAPIError
 from SoftLayer import utils
 
 # Invalid names are ignored due to long method names and short argument names
-# pylint: disable=invalid-name, no-self-use
+# pylint: disable=invalid-name
 
 LOGGER = logging.getLogger(__name__)
 
@@ -284,6 +284,11 @@ class AccountManager(utils.IdentifierMixin, object):
         :param string location: location string
         :returns: Routers
         """
+
+        if mask is None:
+            mask = """
+                 topLevelLocation
+               """
         object_filter = ''
         if location:
             object_filter = {
@@ -350,3 +355,14 @@ class AccountManager(utils.IdentifierMixin, object):
             counts.get('hardwareCount', 0) + \
             counts.get('virtualGuestCount', 0)
         return total
+
+    def getBandwidthDetail(self, identifier):
+        """Gets bandwidth pool detail.
+
+        :returns: bandwidth pool detail
+        """
+        _mask = """activeDetails[allocation],projectedPublicBandwidthUsage, billingCyclePublicBandwidthUsage,
+        hardware[outboundBandwidthUsage,bandwidthAllotmentDetail[allocation]],inboundPublicBandwidthUsage,
+        virtualGuests[outboundPublicBandwidthUsage,bandwidthAllotmentDetail[allocation]],
+        bareMetalInstances[outboundBandwidthUsage,bandwidthAllotmentDetail[allocation]]"""
+        return self.client['SoftLayer_Network_Bandwidth_Version1_Allotment'].getObject(id=identifier, mask=_mask)
