@@ -26,6 +26,10 @@ class StorageManager(utils.IdentifierMixin, object):
         self.client = client
         self.resolvers = [self._get_ids_from_username]
 
+    def _get_ids_from_username(self, username):  # pylint: disable=unused-argument
+        """Should only be actually called from the block/file manager"""
+        return []
+
     def get_volume_count_limits(self):
         """Returns a list of block volume count limit.
 
@@ -69,7 +73,10 @@ class StorageManager(utils.IdentifierMixin, object):
                 'notes',
             ]
             kwargs['mask'] = ','.join(items)
-        return self.client.call('Network_Storage', 'getObject', id=volume_id, **kwargs)
+        return self.client.call('Network_Storage',
+                                'getObject',
+                                id=volume_id,
+                                **kwargs)
 
     def get_volume_access_list(self, volume_id, **kwargs):
         """Returns a list of authorized hosts for a specified volume.
@@ -87,7 +94,10 @@ class StorageManager(utils.IdentifierMixin, object):
                 'allowedIpAddresses[allowedHost[credential]]',
             ]
             kwargs['mask'] = ','.join(items)
-        return self.client.call('Network_Storage', 'getObject', id=volume_id, **kwargs)
+        return self.client.call('Network_Storage',
+                                'getObject',
+                                id=volume_id,
+                                **kwargs)
 
     def get_volume_snapshot_list(self, volume_id, **kwargs):
         """Returns a list of snapshots for the specified volume.
@@ -98,23 +108,48 @@ class StorageManager(utils.IdentifierMixin, object):
         """
         if 'mask' not in kwargs:
             items = [
-                'id',
-                'notes',
-                'snapshotSizeBytes',
-                'storageType[keyName]',
-                'snapshotCreationTimestamp',
-                'intervalSchedule',
-                'hourlySchedule',
-                'dailySchedule',
-                'weeklySchedule'
+                'id', 'notes', 'snapshotSizeBytes', 'storageType[keyName]',
+                'snapshotCreationTimestamp', 'intervalSchedule',
+                'hourlySchedule', 'dailySchedule', 'weeklySchedule'
             ]
 
             kwargs['mask'] = ','.join(items)
 
-        return self.client.call('Network_Storage', 'getSnapshots', id=volume_id, **kwargs)
+        return self.client.call('Network_Storage',
+                                'getSnapshots',
+                                id=volume_id,
+                                **kwargs)
 
-    def authorize_host_to_volume(self, volume_id, hardware_ids=None, virtual_guest_ids=None,
-                                 ip_address_ids=None, subnet_ids=None):
+    def set_volume_snapshot_notification(self, volume_id, enable):
+        """Enables/Disables snapshot space usage threshold warning for a given volume.
+
+        :param volume_id: ID of volume.
+        :param enable: Enable/Disable flag for snapshot warning notification.
+        :return:  Enables/Disables snapshot space usage threshold warning for a given volume.
+        """
+
+        return self.client.call('Network_Storage', 'setSnapshotNotification', enable, id=volume_id)
+
+    def get_volume_snapshot_notification_status(self, volume_id):
+        """returns Enabled/Disabled status of snapshot space usage threshold warning for a given volume.
+
+        :param volume_id: ID of volume.
+        :return:  Enables/Disables snapshot space usage threshold warning for a given volume.
+        """
+        status = self.client.call('Network_Storage', 'getSnapshotNotificationStatus', id=volume_id)
+        # A None status is enabled as well.
+        if status is None:
+            status = 1
+        # We need to force int on the return because otherwise the API will return the string '0'
+        # instead of either a boolean or real int...
+        return int(status)
+
+    def authorize_host_to_volume(self,
+                                 volume_id,
+                                 hardware_ids=None,
+                                 virtual_guest_ids=None,
+                                 ip_address_ids=None,
+                                 subnet_ids=None):
         """Authorizes hosts to Storage Volumes
 
         :param volume_id: The File volume to authorize hosts to
@@ -125,13 +160,20 @@ class StorageManager(utils.IdentifierMixin, object):
         :return: Returns an array of SoftLayer_Network_Storage_Allowed_Host objects
                 which now have access to the given volume
         """
-        host_templates = storage_utils.populate_host_templates(hardware_ids, virtual_guest_ids,
-                                                               ip_address_ids, subnet_ids)
+        host_templates = storage_utils.populate_host_templates(
+            hardware_ids, virtual_guest_ids, ip_address_ids, subnet_ids)
 
-        return self.client.call('Network_Storage', 'allowAccessFromHostList', host_templates, id=volume_id)
+        return self.client.call('Network_Storage',
+                                'allowAccessFromHostList',
+                                host_templates,
+                                id=volume_id)
 
-    def deauthorize_host_to_volume(self, volume_id, hardware_ids=None, virtual_guest_ids=None,
-                                   ip_address_ids=None, subnet_ids=None):
+    def deauthorize_host_to_volume(self,
+                                   volume_id,
+                                   hardware_ids=None,
+                                   virtual_guest_ids=None,
+                                   ip_address_ids=None,
+                                   subnet_ids=None):
         """Revokes authorization of hosts to File Storage Volumes
 
         :param volume_id: The File volume to deauthorize hosts to
@@ -142,10 +184,13 @@ class StorageManager(utils.IdentifierMixin, object):
         :return: Returns an array of SoftLayer_Network_Storage_Allowed_Host objects
                 which have access to the given File volume
         """
-        host_templates = storage_utils.populate_host_templates(hardware_ids, virtual_guest_ids,
-                                                               ip_address_ids, subnet_ids)
+        host_templates = storage_utils.populate_host_templates(
+            hardware_ids, virtual_guest_ids, ip_address_ids, subnet_ids)
 
-        return self.client.call('Network_Storage', 'removeAccessFromHostList', host_templates, id=volume_id)
+        return self.client.call('Network_Storage',
+                                'removeAccessFromHostList',
+                                host_templates,
+                                id=volume_id)
 
     def get_replication_partners(self, volume_id):
         """Acquires list of replicant volumes pertaining to the given volume.
@@ -153,7 +198,9 @@ class StorageManager(utils.IdentifierMixin, object):
         :param volume_id: The ID of the primary volume to be replicated
         :return: Returns an array of SoftLayer_Location objects
         """
-        return self.client.call('Network_Storage', 'getReplicationPartners', id=volume_id)
+        return self.client.call('Network_Storage',
+                                'getReplicationPartners',
+                                id=volume_id)
 
     def get_replication_locations(self, volume_id):
         """Acquires list of the datacenters to which a volume can be replicated.
@@ -161,9 +208,16 @@ class StorageManager(utils.IdentifierMixin, object):
         :param volume_id: The ID of the primary volume to be replicated
         :return: Returns an array of SoftLayer_Network_Storage objects
         """
-        return self.client.call('Network_Storage', 'getValidReplicationTargetDatacenterLocations', id=volume_id)
+        return self.client.call('Network_Storage',
+                                'getValidReplicationTargetDatacenterLocations',
+                                id=volume_id)
 
-    def order_replicant_volume(self, volume_id, snapshot_schedule, location, tier=None, os_type=None):
+    def order_replicant_volume(self,
+                               volume_id,
+                               snapshot_schedule,
+                               location,
+                               tier=None,
+                               os_type=None):
         """Places an order for a replicant volume.
 
         :param volume_id: The ID of the primary volume to be replicated
@@ -182,15 +236,17 @@ class StorageManager(utils.IdentifierMixin, object):
                      'weeklySchedule,storageType[keyName],provisionedIops'
         block_volume = self.get_volume_details(volume_id, mask=block_mask)
 
-        storage_class = storage_utils.block_or_file(block_volume['storageType']['keyName'])
+        storage_class = storage_utils.block_or_file(
+            block_volume['storageType']['keyName'])
 
         order = storage_utils.prepare_replicant_order_object(
-            self, snapshot_schedule, location, tier, block_volume, storage_class
-        )
+            self, snapshot_schedule, location, tier, block_volume,
+            storage_class)
 
         if storage_class == 'block':
             if os_type is None:
-                if isinstance(utils.lookup(block_volume, 'osType', 'keyName'), str):
+                if isinstance(utils.lookup(block_volume, 'osType', 'keyName'),
+                              str):
                     os_type = block_volume['osType']['keyName']
                 else:
                     raise exceptions.SoftLayerError(
@@ -200,9 +256,15 @@ class StorageManager(utils.IdentifierMixin, object):
 
         return self.client.call('Product_Order', 'placeOrder', order)
 
-    def order_duplicate_volume(self, origin_volume_id, origin_snapshot_id=None, duplicate_size=None,
-                               duplicate_iops=None, duplicate_tier_level=None, duplicate_snapshot_size=None,
-                               hourly_billing_flag=False, dependent_duplicate=False):
+    def order_duplicate_volume(self,
+                               origin_volume_id,
+                               origin_snapshot_id=None,
+                               duplicate_size=None,
+                               duplicate_iops=None,
+                               duplicate_tier_level=None,
+                               duplicate_snapshot_size=None,
+                               hourly_billing_flag=False,
+                               dependent_duplicate=False):
         """Places an order for a duplicate volume.
 
         :param origin_volume_id: The ID of the origin volume to be duplicated
@@ -219,19 +281,23 @@ class StorageManager(utils.IdentifierMixin, object):
                      'storageType[keyName],capacityGb,originalVolumeSize,' \
                      'provisionedIops,storageTierLevel,osType[keyName],' \
                      'staasVersion,hasEncryptionAtRest'
-        origin_volume = self.get_volume_details(origin_volume_id, mask=block_mask)
-        storage_class = storage_utils.block_or_file(origin_volume['storageType']['keyName'])
+        origin_volume = self.get_volume_details(origin_volume_id,
+                                                mask=block_mask)
+        storage_class = storage_utils.block_or_file(
+            origin_volume['storageType']['keyName'])
 
         order = storage_utils.prepare_duplicate_order_object(
             self, origin_volume, duplicate_iops, duplicate_tier_level,
-            duplicate_size, duplicate_snapshot_size, storage_class, hourly_billing_flag
-        )
+            duplicate_size, duplicate_snapshot_size, storage_class,
+            hourly_billing_flag)
 
         if storage_class == 'block':
-            if isinstance(utils.lookup(origin_volume, 'osType', 'keyName'), str):
+            if isinstance(utils.lookup(origin_volume, 'osType', 'keyName'),
+                          str):
                 os_type = origin_volume['osType']['keyName']
             else:
-                raise exceptions.SoftLayerError("Cannot find origin volume's os-type")
+                raise exceptions.SoftLayerError(
+                    "Cannot find origin volume's os-type")
 
             order['osFormatType'] = {'keyName': os_type}
 
@@ -243,7 +309,11 @@ class StorageManager(utils.IdentifierMixin, object):
 
         return self.client.call('Product_Order', 'placeOrder', order)
 
-    def order_modified_volume(self, volume_id, new_size=None, new_iops=None, new_tier_level=None):
+    def order_modified_volume(self,
+                              volume_id,
+                              new_size=None,
+                              new_iops=None,
+                              new_tier_level=None):
         """Places an order for modifying an existing block volume.
 
         :param volume_id: The ID of the volume to be modified
@@ -267,8 +337,7 @@ class StorageManager(utils.IdentifierMixin, object):
         volume = self.get_volume_details(volume_id, mask=block_mask)
 
         order = storage_utils.prepare_modify_order_object(
-            self, volume, new_iops, new_tier_level, new_size
-        )
+            self, volume, new_iops, new_tier_level, new_size)
 
         return self.client.call('Product_Order', 'placeOrder', order)
 
@@ -280,14 +349,19 @@ class StorageManager(utils.IdentifierMixin, object):
         :return: Returns true if success
         """
         template = {'notes': note}
-        return self.client.call('SoftLayer_Network_Storage', 'editObject', template, id=volume_id)
+        return self.client.call('SoftLayer_Network_Storage',
+                                'editObject',
+                                template,
+                                id=volume_id)
 
     def delete_snapshot(self, snapshot_id):
         """Deletes the specified snapshot object.
 
         :param snapshot_id: The ID of the snapshot object to delete.
         """
-        return self.client.call('Network_Storage', 'deleteObject', id=snapshot_id)
+        return self.client.call('Network_Storage',
+                                'deleteObject',
+                                id=snapshot_id)
 
     def create_snapshot(self, volume_id, notes='', **kwargs):
         """Creates a snapshot on the given block volume.
@@ -296,9 +370,14 @@ class StorageManager(utils.IdentifierMixin, object):
         :param string notes: The notes or "name" to assign the snapshot
         :return: Returns the id of the new snapshot
         """
-        return self.client.call('Network_Storage', 'createSnapshot', notes, id=volume_id, **kwargs)
+        return self.client.call('Network_Storage',
+                                'createSnapshot',
+                                notes,
+                                id=volume_id,
+                                **kwargs)
 
-    def order_snapshot_space(self, volume_id, capacity, tier, upgrade, **kwargs):
+    def order_snapshot_space(self, volume_id, capacity, tier, upgrade,
+                             **kwargs):
         """Orders snapshot space for the given block volume.
 
         :param integer volume_id: The id of the volume
@@ -312,11 +391,15 @@ class StorageManager(utils.IdentifierMixin, object):
                       'staasVersion,hasEncryptionAtRest'
         volume = self.get_volume_details(volume_id, mask=object_mask, **kwargs)
 
-        order = storage_utils.prepare_snapshot_order_object(self, volume, capacity, tier, upgrade)
+        order = storage_utils.prepare_snapshot_order_object(
+            self, volume, capacity, tier, upgrade)
 
         return self.client.call('Product_Order', 'placeOrder', order)
 
-    def cancel_snapshot_space(self, volume_id, reason='No longer needed', immediate=False):
+    def cancel_snapshot_space(self,
+                              volume_id,
+                              reason='No longer needed',
+                              immediate=False):
         """Cancels snapshot space for a given volume.
 
         :param integer volume_id: The volume ID
@@ -328,7 +411,8 @@ class StorageManager(utils.IdentifierMixin, object):
         volume = self.get_volume_details(volume_id, mask=object_mask)
 
         if 'activeChildren' not in volume['billingItem']:
-            raise exceptions.SoftLayerError('No snapshot space found to cancel')
+            raise exceptions.SoftLayerError(
+                'No snapshot space found to cancel')
 
         children_array = volume['billingItem']['activeChildren']
         billing_item_id = None
@@ -339,14 +423,21 @@ class StorageManager(utils.IdentifierMixin, object):
                 break
 
         if not billing_item_id:
-            raise exceptions.SoftLayerError('No snapshot space found to cancel')
+            raise exceptions.SoftLayerError(
+                'No snapshot space found to cancel')
 
         if utils.lookup(volume, 'billingItem', 'hourlyFlag'):
             immediate = True
 
-        return self.client.call('SoftLayer_Billing_Item', 'cancelItem', immediate, True, reason, id=billing_item_id)
+        return self.client.call('SoftLayer_Billing_Item',
+                                'cancelItem',
+                                immediate,
+                                True,
+                                reason,
+                                id=billing_item_id)
 
-    def enable_snapshots(self, volume_id, schedule_type, retention_count, minute, hour, day_of_week, **kwargs):
+    def enable_snapshots(self, volume_id, schedule_type, retention_count,
+                         minute, hour, day_of_week, **kwargs):
         """Enables snapshots for a specific block volume at a given schedule
 
         :param integer volume_id: The id of the volume
@@ -357,8 +448,15 @@ class StorageManager(utils.IdentifierMixin, object):
         :param string day_of_week: Day when to take snapshot
         :return: Returns whether successfully scheduled or not
         """
-        return self.client.call('Network_Storage', 'enableSnapshots', schedule_type, retention_count,
-                                minute, hour, day_of_week, id=volume_id, **kwargs)
+        return self.client.call('Network_Storage',
+                                'enableSnapshots',
+                                schedule_type,
+                                retention_count,
+                                minute,
+                                hour,
+                                day_of_week,
+                                id=volume_id,
+                                **kwargs)
 
     def disable_snapshots(self, volume_id, schedule_type):
         """Disables snapshots for a specific block volume at a given schedule
@@ -367,7 +465,10 @@ class StorageManager(utils.IdentifierMixin, object):
         :param string schedule_type: 'HOURLY'|'DAILY'|'WEEKLY'
         :return: Returns whether successfully disabled or not
         """
-        return self.client.call('Network_Storage', 'disableSnapshots', schedule_type, id=volume_id)
+        return self.client.call('Network_Storage',
+                                'disableSnapshots',
+                                schedule_type,
+                                id=volume_id)
 
     def list_volume_schedules(self, volume_id):
         """Lists schedules for a given volume
@@ -376,7 +477,10 @@ class StorageManager(utils.IdentifierMixin, object):
         :return: Returns list of schedules assigned to a given volume
         """
         object_mask = 'schedules[type,properties[type]]'
-        volume_detail = self.client.call('Network_Storage', 'getObject', id=volume_id, mask=object_mask)
+        volume_detail = self.client.call('Network_Storage',
+                                         'getObject',
+                                         id=volume_id,
+                                         mask=object_mask)
 
         return utils.lookup(volume_detail, 'schedules')
 
@@ -387,7 +491,10 @@ class StorageManager(utils.IdentifierMixin, object):
         :param integer snapshot_id: The id of the restore point
         :return: Returns whether succesfully restored or not
         """
-        return self.client.call('Network_Storage', 'restoreFromSnapshot', snapshot_id, id=volume_id)
+        return self.client.call('Network_Storage',
+                                'restoreFromSnapshot',
+                                snapshot_id,
+                                id=volume_id)
 
     def failover_to_replicant(self, volume_id, replicant_id):
         """Failover to a volume replicant.
@@ -396,7 +503,10 @@ class StorageManager(utils.IdentifierMixin, object):
         :param integer replicant_id: ID of replicant to failover to
         :return: Returns whether failover was successful or not
         """
-        return self.client.call('Network_Storage', 'failoverToReplicant', replicant_id, id=volume_id)
+        return self.client.call('Network_Storage',
+                                'failoverToReplicant',
+                                replicant_id,
+                                id=volume_id)
 
     def disaster_recovery_failover_to_replicant(self, volume_id, replicant_id):
         """Disaster Recovery Failover to a volume replicant.
@@ -405,7 +515,10 @@ class StorageManager(utils.IdentifierMixin, object):
         :param integer replicant: ID of replicant to failover to
         :return: Returns whether failover to successful or not
         """
-        return self.client.call('Network_Storage', 'disasterRecoveryFailoverToReplicant', replicant_id, id=volume_id)
+        return self.client.call('Network_Storage',
+                                'disasterRecoveryFailoverToReplicant',
+                                replicant_id,
+                                id=volume_id)
 
     def failback_from_replicant(self, volume_id):
         """Failback from a volume replicant.
@@ -413,9 +526,14 @@ class StorageManager(utils.IdentifierMixin, object):
         :param integer volume_id: The id of the volume
         :return: Returns whether failback was successful or not
         """
-        return self.client.call('Network_Storage', 'failbackFromReplicant', id=volume_id)
+        return self.client.call('Network_Storage',
+                                'failbackFromReplicant',
+                                id=volume_id)
 
-    def cancel_volume(self, volume_id, reason='No longer needed', immediate=False):
+    def cancel_volume(self,
+                      volume_id,
+                      reason='No longer needed',
+                      immediate=False):
         """Cancels the given storage volume.
 
         :param integer volume_id: The volume ID
@@ -426,14 +544,20 @@ class StorageManager(utils.IdentifierMixin, object):
         volume = self.get_volume_details(volume_id, mask=object_mask)
 
         if 'billingItem' not in volume:
-            raise exceptions.SoftLayerError("Storage Volume was already cancelled")
+            raise exceptions.SoftLayerError(
+                "Storage Volume was already cancelled")
 
         billing_item_id = volume['billingItem']['id']
 
         if utils.lookup(volume, 'billingItem', 'hourlyFlag'):
             immediate = True
 
-        return self.client.call('SoftLayer_Billing_Item', 'cancelItem', immediate, True, reason, id=billing_item_id)
+        return self.client.call('SoftLayer_Billing_Item',
+                                'cancelItem',
+                                immediate,
+                                True,
+                                reason,
+                                id=billing_item_id)
 
     def refresh_dupe(self, volume_id, snapshot_id):
         """"Refresh a duplicate volume with a snapshot from its parent.
@@ -441,11 +565,44 @@ class StorageManager(utils.IdentifierMixin, object):
         :param integer volume_id: The id of the volume
         :param integer snapshot_id: The id of the snapshot
         """
-        return self.client.call('Network_Storage', 'refreshDuplicate', snapshot_id, id=volume_id)
+        return self.client.call('Network_Storage',
+                                'refreshDuplicate',
+                                snapshot_id,
+                                id=volume_id)
 
     def convert_dep_dupe(self, volume_id):
         """Convert a dependent duplicate volume to an independent volume.
 
         :param integer volume_id: The id of the volume.
         """
-        return self.client.call('Network_Storage', 'convertCloneDependentToIndependent', id=volume_id)
+        return self.client.call('Network_Storage',
+                                'convertCloneDependentToIndependent',
+                                id=volume_id)
+
+    def convert_dupe_status(self, volume_id):
+        """Get the Clone split/move status completion of a duplicate volume
+
+        :param integer volume_id: The id of the volume.
+        """
+        return self.client.call('Network_Storage',
+                                'getDuplicateConversionStatus',
+                                id=volume_id)
+
+    def get_network_message_delivery_accounts(self, object_id):
+        """Return  object data of the cloud storage.
+
+        :param object_id cloud object storage identifier
+        Returns: Get instances
+        """
+        object_mask = 'mask[uuid,credentials]'
+        return self.client.call('SoftLayer_Network_Storage_Hub_Cleversafe_Account',
+                                'getObject', mask=object_mask, id=object_id)
+
+    def get_end_points(self, object_id):
+        """Returns a collection of endpoint URLs available to this IBM Cloud Object Storage account.
+
+        :param object_id cloud object storage identifier
+        Returns: Returns a collection of endpoint URLs.
+        """
+        return self.client.call('SoftLayer_Network_Storage_Hub_Cleversafe_Account',
+                                'getEndpoints',  id=object_id)
